/*
Copyright [2020] [https://www.xiaonuo.vip]

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：

1.请不要删除和修改根目录下的LICENSE文件。
2.请不要删除和修改Snowy源码头部的版权声明。
3.请保留源码和相关描述文件的项目出处，作者声明等。
4.分发源码时候，请注明软件出处 https://gitee.com/xiaonuobase/snowy
5.在修改包名，模块名称，项目代码等时，请注明软件出处 https://gitee.com/xiaonuobase/snowy
6.若您的项目无法满足以上几点，可申请商业授权，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.huimv.modular.alarmrecord.controller;

import com.huimv.core.annotion.BusinessLog;
import com.huimv.core.annotion.Permission;
import com.huimv.core.enums.LogAnnotionOpTypeEnum;
import com.huimv.core.pojo.response.ResponseData;
import com.huimv.core.pojo.response.SuccessResponseData;
import com.huimv.modular.alarmrecord.param.AlarmRecordParam;
import com.huimv.modular.alarmrecord.service.AlarmRecordService;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import javax.annotation.Resource;
import java.util.List;

/**
 * 报警记录控制器
 *
 * @author ydd
 * @date 2021-08-20 13:27:00
 */
@RestController
public class AlarmRecordController {

    @Resource
    private AlarmRecordService alarmRecordService;

    /**
     * 查询报警记录
     *
     * @author ydd
     * @date 2021-08-20 13:27:00
     */
    @Permission
    @GetMapping("/alarmRecord/page")
    @BusinessLog(title = "报警记录_查询", opType = LogAnnotionOpTypeEnum.QUERY)
    public ResponseData page(AlarmRecordParam alarmRecordParam) {
        return new SuccessResponseData(alarmRecordService.page(alarmRecordParam));
    }

    /**
     * 添加报警记录
     *
     * @author ydd
     * @date 2021-08-20 13:27:00
     */
    @Permission
    @PostMapping("/alarmRecord/add")
    @BusinessLog(title = "报警记录_增加", opType = LogAnnotionOpTypeEnum.ADD)
    public ResponseData add(@RequestBody @Validated(AlarmRecordParam.add.class) AlarmRecordParam alarmRecordParam) {
            alarmRecordService.add(alarmRecordParam);
        return new SuccessResponseData();
    }

    /**
     * 删除报警记录，可批量删除
     * @author ydd
     * @date 2021-08-20 13:27:00
     */
    @Permission
    @PostMapping("/alarmRecord/delete")
    @BusinessLog(title = "报警记录_删除", opType = LogAnnotionOpTypeEnum.DELETE)
    public ResponseData delete(@RequestBody @Validated(AlarmRecordParam.delete.class) List<AlarmRecordParam> alarmRecordParamList) {
            alarmRecordService.delete(alarmRecordParamList);
        return new SuccessResponseData();
    }

    /**
     * 编辑报警记录
     *
     * @author ydd
     * @date 2021-08-20 13:27:00
     */
    @Permission
    @PostMapping("/alarmRecord/edit")
    @BusinessLog(title = "报警记录_编辑", opType = LogAnnotionOpTypeEnum.EDIT)
    public ResponseData edit(@RequestBody @Validated(AlarmRecordParam.edit.class) AlarmRecordParam alarmRecordParam) {
            alarmRecordService.edit(alarmRecordParam);
        return new SuccessResponseData();
    }

    /**
     * 查看报警记录
     *
     * @author ydd
     * @date 2021-08-20 13:27:00
     */
    @Permission
    @GetMapping("/alarmRecord/detail")
    @BusinessLog(title = "报警记录_查看", opType = LogAnnotionOpTypeEnum.DETAIL)
    public ResponseData detail(@Validated(AlarmRecordParam.detail.class) AlarmRecordParam alarmRecordParam) {
        return new SuccessResponseData(alarmRecordService.detail(alarmRecordParam));
    }

    /**
     * 报警记录列表
     *
     * @author ydd
     * @date 2021-08-20 13:27:00
     */
    @Permission
    @GetMapping("/alarmRecord/list")
    @BusinessLog(title = "报警记录_列表", opType = LogAnnotionOpTypeEnum.QUERY)
    public ResponseData list(AlarmRecordParam alarmRecordParam) {
        return new SuccessResponseData(alarmRecordService.list(alarmRecordParam));
    }

    /**
     * 导出系统用户
     *
     * @author ydd
     * @date 2021-08-20 13:27:00
     */
    @Permission
    @GetMapping("/alarmRecord/export")
    @BusinessLog(title = "报警记录_导出", opType = LogAnnotionOpTypeEnum.EXPORT)
    public void export(AlarmRecordParam alarmRecordParam) {
        alarmRecordService.export(alarmRecordParam);
    }

}
