/*
Copyright [2020] [https://www.xiaonuo.vip]

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：

1.请不要删除和修改根目录下的LICENSE文件。
2.请不要删除和修改Snowy源码头部的版权声明。
3.请保留源码和相关描述文件的项目出处，作者声明等。
4.分发源码时候，请注明软件出处 https://gitee.com/xiaonuobase/snowy
5.在修改包名，模块名称，项目代码等时，请注明软件出处 https://gitee.com/xiaonuobase/snowy
6.若您的项目无法满足以上几点，可申请商业授权，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.huimv.modular.baseregion.controller;

import com.huimv.core.annotion.BusinessLog;
import com.huimv.core.annotion.DataScope;
import com.huimv.core.annotion.Permission;
import com.huimv.core.enums.LogAnnotionOpTypeEnum;
import com.huimv.core.pojo.response.ResponseData;
import com.huimv.core.pojo.response.SuccessResponseData;
import com.huimv.modular.baseregion.param.BaseRegionParam;
import com.huimv.modular.baseregion.service.BaseRegionService;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import javax.annotation.Resource;
import java.util.List;

/**
 * 区域管理控制器
 *
 * @author yinhao
 * @date 2021-08-10 16:57:21
 */
@RestController
public class BaseRegionController {

    @Resource
    private BaseRegionService baseRegionService;

    /**
     * 查询区域管理
     *
     * @author yinhao
     * @date 2021-08-10 16:57:21
     */
    @Permission
    @GetMapping("/baseRegion/page")
    @BusinessLog(title = "区域管理_查询", opType = LogAnnotionOpTypeEnum.QUERY)
    public ResponseData page(BaseRegionParam baseRegionParam) {
        return new SuccessResponseData(baseRegionService.page(baseRegionParam));
    }

    /**
     * 添加区域管理
     *
     * @author yinhao
     * @date 2021-08-10 16:57:21
     */
    @Permission
    @PostMapping("/baseRegion/add")
    @BusinessLog(title = "区域管理_增加", opType = LogAnnotionOpTypeEnum.ADD)
    public ResponseData add(@RequestBody @Validated(BaseRegionParam.add.class) BaseRegionParam baseRegionParam) {
            baseRegionService.add(baseRegionParam);
        return new SuccessResponseData();
    }

    /**
     * 删除区域管理，可批量删除
     *
     * @author yinhao
     * @date 2021-08-10 16:57:21
     */
    @Permission
    @PostMapping("/baseRegion/delete")
    @BusinessLog(title = "区域管理_删除", opType = LogAnnotionOpTypeEnum.DELETE)
    public ResponseData delete(@RequestBody @Validated(BaseRegionParam.delete.class) List<BaseRegionParam> baseRegionParamList) {
            baseRegionService.delete(baseRegionParamList);
        return new SuccessResponseData();
    }

    /**
     * 编辑区域管理
     *
     * @author yinhao
     * @date 2021-08-10 16:57:21
     */
    @Permission
    @PostMapping("/baseRegion/edit")
    @BusinessLog(title = "区域管理_编辑", opType = LogAnnotionOpTypeEnum.EDIT)
    public ResponseData edit(@RequestBody @Validated(BaseRegionParam.edit.class) BaseRegionParam baseRegionParam) {
            baseRegionService.edit(baseRegionParam);
        return new SuccessResponseData();
    }

    /**
     * 查看区域管理
     *
     * @author yinhao
     * @date 2021-08-10 16:57:21
     */
    @Permission
    @GetMapping("/baseRegion/detail")
    @BusinessLog(title = "区域管理_查看", opType = LogAnnotionOpTypeEnum.DETAIL)
    public ResponseData detail(@Validated(BaseRegionParam.detail.class) BaseRegionParam baseRegionParam) {
        return new SuccessResponseData(baseRegionService.detail(baseRegionParam));
    }

    /**
     * 区域管理列表
     *
     * @author yinhao
     * @date 2021-08-10 16:57:21
     */
    @Permission
    @GetMapping("/baseRegion/list")
    @BusinessLog(title = "区域管理_列表", opType = LogAnnotionOpTypeEnum.QUERY)
    public ResponseData list(BaseRegionParam baseRegionParam) {
        return new SuccessResponseData(baseRegionService.list(baseRegionParam));
    }

    /**
     * 导出系统用户
     *
     * @author yinhao
     * @date 2021-08-10 16:57:21
     */
    @Permission
    @GetMapping("/baseRegion/export")
    @BusinessLog(title = "区域管理_导出", opType = LogAnnotionOpTypeEnum.EXPORT)
    public void export(BaseRegionParam baseRegionParam) {
        baseRegionService.export(baseRegionParam);
    }

    @Permission
    @DataScope
    @GetMapping("/baseRegion/test")
    @BusinessLog(title = "yxx_test", opType = LogAnnotionOpTypeEnum.EXPORT)
    public void test() {
        baseRegionService.test();
    }

}
