/*
Copyright [2020] [https://www.xiaonuo.vip]

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：

1.请不要删除和修改根目录下的LICENSE文件。
2.请不要删除和修改Snowy源码头部的版权声明。
3.请保留源码和相关描述文件的项目出处，作者声明等。
4.分发源码时候，请注明软件出处 https://gitee.com/xiaonuobase/snowy
5.在修改包名，模块名称，项目代码等时，请注明软件出处 https://gitee.com/xiaonuobase/snowy
6.若您的项目无法满足以上几点，可申请商业授权，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.huimv.modular.baseregion.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.core.context.login.LoginContextHolder;
import com.huimv.core.exception.ServiceException;
import com.huimv.core.factory.PageFactory;
import com.huimv.core.pojo.page.PageResult;
import com.huimv.core.util.PoiUtil;
import com.huimv.modular.baseregion.entity.BaseRegion;
import com.huimv.modular.baseregion.enums.BaseRegionExceptionEnum;
import com.huimv.modular.baseregion.mapper.BaseRegionMapper;
import com.huimv.modular.baseregion.param.BaseRegionParam;
import com.huimv.modular.baseregion.service.BaseRegionService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.net.ContentHandler;
import java.util.List;

/**
 * 区域管理service接口实现类
 *
 * @author yinhao
 * @date 2021-08-10 16:57:21
 */
@Service
public class BaseRegionServiceImpl extends ServiceImpl<BaseRegionMapper, BaseRegion> implements BaseRegionService {

    @Override
    public PageResult<BaseRegion> page(BaseRegionParam baseRegionParam) {
        QueryWrapper<BaseRegion> queryWrapper = new QueryWrapper<>();
        if (ObjectUtil.isNotNull(baseRegionParam)) {

            // 根据行政区域代码 查询
            if (ObjectUtil.isNotEmpty(baseRegionParam.getRegionCode())) {
                queryWrapper.lambda().eq(BaseRegion::getRegionCode, baseRegionParam.getRegionCode());
            }
            // 根据行政区域名称 查询
            if (ObjectUtil.isNotEmpty(baseRegionParam.getRegionName())) {
                queryWrapper.lambda().eq(BaseRegion::getRegionName, baseRegionParam.getRegionName());
            }
            // 根据上级行政区域代码 查询
            if (ObjectUtil.isNotEmpty(baseRegionParam.getParentCode())) {
                queryWrapper.lambda().eq(BaseRegion::getParentCode, baseRegionParam.getParentCode());
            }
            // 根据牧场编码 查询
            if (ObjectUtil.isNotEmpty(baseRegionParam.getFarmCode())) {
                queryWrapper.lambda().eq(BaseRegion::getFarmCode, baseRegionParam.getFarmCode());
            }
        }
        return new PageResult<>(this.page(PageFactory.defaultPage(), queryWrapper));
    }

    @Override
    public List<BaseRegion> list(BaseRegionParam baseRegionParam) {
        return this.list();
    }

    @Override
    public void add(BaseRegionParam baseRegionParam) {
        BaseRegion baseRegion = new BaseRegion();
        BeanUtil.copyProperties(baseRegionParam, baseRegion);
        this.save(baseRegion);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BaseRegionParam> baseRegionParamList) {
        baseRegionParamList.forEach(baseRegionParam -> {
            this.removeById(baseRegionParam.getId());
        });
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BaseRegionParam baseRegionParam) {
        BaseRegion baseRegion = this.queryBaseRegion(baseRegionParam);
        BeanUtil.copyProperties(baseRegionParam, baseRegion);
        this.updateById(baseRegion);
    }

    @Override
    public BaseRegion detail(BaseRegionParam baseRegionParam) {
        return this.queryBaseRegion(baseRegionParam);
    }

    /**
     * 获取区域管理
     *
     * @author yinhao
     * @date 2021-08-10 16:57:21
     */
    private BaseRegion queryBaseRegion(BaseRegionParam baseRegionParam) {
        BaseRegion baseRegion = this.getById(baseRegionParam.getId());
        if (ObjectUtil.isNull(baseRegion)) {
            throw new ServiceException(BaseRegionExceptionEnum.NOT_EXIST);
        }
        return baseRegion;
    }

    @Override
    public void export(BaseRegionParam baseRegionParam) {
        List<BaseRegion> list = this.list(baseRegionParam);
        PoiUtil.exportExcelWithStream("BaseRegion.xls", BaseRegion.class, list);
    }

    @Override
    public void test() {
        LoginContextHolder.me().getLoginUserRoleIds();
        LoginContextHolder.me().getSysLoginUser();
        LoginContextHolder.me().getSysLoginUserOrgId();
    }
}
