/*
Copyright [2020] [https://www.xiaonuo.vip]

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：

1.请不要删除和修改根目录下的LICENSE文件。
2.请不要删除和修改Snowy源码头部的版权声明。
3.请保留源码和相关描述文件的项目出处，作者声明等。
4.分发源码时候，请注明软件出处 https://gitee.com/xiaonuobase/snowy
5.在修改包名，模块名称，项目代码等时，请注明软件出处 https://gitee.com/xiaonuobase/snowy
6.若您的项目无法满足以上几点，可申请商业授权，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.huimv.modular.eartagregister.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

import com.huimv.core.factory.PageFactory;
import com.huimv.core.pojo.page.PageResult;
import com.huimv.modular.eartagdata.entity.EartagData;
import com.huimv.modular.eartagregister.entity.EartagRegister;
import com.huimv.modular.eartagregister.entity.EartagRegisterVO;
import com.huimv.modular.eartagregister.mapper.EartagRegisterMapper;
import com.huimv.modular.eartagregister.service.EartagRegisterService;
import com.huimv.modular.utils.util.StringUtilsWork;
import com.huimv.modular.yesterdaypig.entity.YesterdayPig;
import com.huimv.modular.yesterdaypig.mapper.YesterdayPigMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.text.ParseException;
import java.util.List;

/**
 * 耳标注册service接口实现类
 *
 * @author yinhao
 * @date 2021-08-17 16:17:54
 */
@Service
public class EartagRegisterServiceImpl extends ServiceImpl<EartagRegisterMapper, EartagRegister> implements EartagRegisterService {

    @Autowired
    private YesterdayPigMapper yesterdayPigMapper;

    @Autowired
    private EartagRegisterMapper eartagRegisterMapper;

    @Override
    public PageResult<EartagRegister> query(EartagRegisterVO eartagRegisterVO) throws ParseException {


        LambdaQueryWrapper<EartagRegister> wrapper = Wrappers.lambdaQuery();

        //耳标号模糊查询
        if (StringUtilsWork.isNotBlank(eartagRegisterVO.getEartagNo())) {
            wrapper.like(EartagRegister::getEartagNo, eartagRegisterVO.getEartagNo());
        }
        //位置模糊查询
        if (StringUtilsWork.isNotBlank(eartagRegisterVO.getLocation()) ) {
            wrapper.like(EartagRegister::getLocation, eartagRegisterVO.getLocation());
        }
        wrapper.orderByAsc(EartagRegister::getId);
        System.out.println(eartagRegisterVO.getLocation());


        PageResult<EartagRegister>  EartagDataPageResult = new PageResult<>();

        IPage<EartagRegister> iPage = eartagRegisterMapper.selectPage(new Page<>(eartagRegisterVO.getPageNo(), eartagRegisterVO.getPageSize()),
                wrapper);

        EartagDataPageResult.setRows(iPage.getRecords());
        EartagDataPageResult.setPageSize(eartagRegisterVO.getPageSize());
        EartagDataPageResult.setPageNo(eartagRegisterVO.getPageNo());
        EartagDataPageResult.setTotalPage( Integer.valueOf(String.valueOf(iPage.getPages())) );
        EartagDataPageResult.setTotalRows( Integer.valueOf(String.valueOf(iPage.getTotal())) );

        return EartagDataPageResult ;
    }


    

    @Transactional
    @Override
    public void updateYestdayPig() {
        List<EartagRegister> list = this.list();
        yesterdayPigMapper.delete(null);
        for (EartagRegister eartagRegister : list) {
            YesterdayPig yesterdayPig = new YesterdayPig();
            BeanUtil.copyProperties(eartagRegister,yesterdayPig);
            yesterdayPigMapper.insert(yesterdayPig);
        }

    }
}
