/*
Copyright [2020] [https://www.xiaonuo.vip]

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：

1.请不要删除和修改根目录下的LICENSE文件。
2.请不要删除和修改Snowy源码头部的版权声明。
3.请保留源码和相关描述文件的项目出处，作者声明等。
4.分发源码时候，请注明软件出处 https://gitee.com/xiaonuobase/snowy
5.在修改包名，模块名称，项目代码等时，请注明软件出处 https://gitee.com/xiaonuobase/snowy
6.若您的项目无法满足以上几点，可申请商业授权，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.huimv.modular.movepigpen.controller;

import com.huimv.core.annotion.BusinessLog;
import com.huimv.core.annotion.Permission;
import com.huimv.core.enums.LogAnnotionOpTypeEnum;
import com.huimv.core.pojo.response.ResponseData;
import com.huimv.core.pojo.response.SuccessResponseData;
import com.huimv.modular.movepigpen.param.MovePigpenParam;
import com.huimv.modular.movepigpen.service.MovePigpenService;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import javax.annotation.Resource;
import java.util.List;

/**
 * 转舍控制器
 *
 * @author ydd
 * @date 2021-08-20 17:03:16
 */
@RestController
public class MovePigpenController {

    @Resource
    private MovePigpenService movePigpenService;

    /**
     * 查询转舍
     *
     * @author ydd
     * @date 2021-08-20 17:03:16
     */
    @Permission
    @GetMapping("/movePigpen/page")
    @BusinessLog(title = "转舍_查询", opType = LogAnnotionOpTypeEnum.QUERY)
    public ResponseData page(MovePigpenParam movePigpenParam) {
        return new SuccessResponseData(movePigpenService.page(movePigpenParam));
    }

    /**
     * 添加转舍
     *
     * @author ydd
     * @date 2021-08-20 17:03:16
     */
    @Permission
    @PostMapping("/movePigpen/add")
    @BusinessLog(title = "转舍_增加", opType = LogAnnotionOpTypeEnum.ADD)
    public ResponseData add(@RequestBody @Validated(MovePigpenParam.add.class) MovePigpenParam movePigpenParam) {
            movePigpenService.add(movePigpenParam);
        return new SuccessResponseData();
    }

    /**
     * 删除转舍，可批量删除
     *
     * @author ydd
     * @date 2021-08-20 17:03:16
     */
    @Permission
    @PostMapping("/movePigpen/delete")
    @BusinessLog(title = "转舍_删除", opType = LogAnnotionOpTypeEnum.DELETE)
    public ResponseData delete(@RequestBody @Validated(MovePigpenParam.delete.class) List<MovePigpenParam> movePigpenParamList) {
            movePigpenService.delete(movePigpenParamList);
        return new SuccessResponseData();
    }

    /**
     * 编辑转舍
     *
     * @author ydd
     * @date 2021-08-20 17:03:16
     */
    @Permission
    @PostMapping("/movePigpen/edit")
    @BusinessLog(title = "转舍_编辑", opType = LogAnnotionOpTypeEnum.EDIT)
    public ResponseData edit(@RequestBody @Validated(MovePigpenParam.edit.class) MovePigpenParam movePigpenParam) {
            movePigpenService.edit(movePigpenParam);
        return new SuccessResponseData();
    }

    /**
     * 查看转舍
     *
     * @author ydd
     * @date 2021-08-20 17:03:16
     */
    @Permission
    @GetMapping("/movePigpen/detail")
    @BusinessLog(title = "转舍_查看", opType = LogAnnotionOpTypeEnum.DETAIL)
    public ResponseData detail(@Validated(MovePigpenParam.detail.class) MovePigpenParam movePigpenParam) {
        return new SuccessResponseData(movePigpenService.detail(movePigpenParam));
    }

    /**
     * 转舍列表
     *
     * @author ydd
     * @date 2021-08-20 17:03:16
     */
    @Permission
    @GetMapping("/movePigpen/list")
    @BusinessLog(title = "转舍_列表", opType = LogAnnotionOpTypeEnum.QUERY)
    public ResponseData list(MovePigpenParam movePigpenParam) {
        return new SuccessResponseData(movePigpenService.list(movePigpenParam));
    }

    /**
     * 导出系统用户
     *
     * @author ydd
     * @date 2021-08-20 17:03:16
     */
    @Permission
    @GetMapping("/movePigpen/export")
    @BusinessLog(title = "转舍_导出", opType = LogAnnotionOpTypeEnum.EXPORT)
    public void export(MovePigpenParam movePigpenParam) {
        movePigpenService.export(movePigpenParam);
    }

}
