/*
Copyright [2020] [https://www.xiaonuo.vip]

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：

1.请不要删除和修改根目录下的LICENSE文件。
2.请不要删除和修改Snowy源码头部的版权声明。
3.请保留源码和相关描述文件的项目出处，作者声明等。
4.分发源码时候，请注明软件出处 https://gitee.com/xiaonuobase/snowy
5.在修改包名，模块名称，项目代码等时，请注明软件出处 https://gitee.com/xiaonuobase/snowy
6.若您的项目无法满足以上几点，可申请商业授权，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.huimv.modular.rawdata.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.core.consts.CommonConstant;
import com.huimv.core.enums.CommonStatusEnum;
import com.huimv.core.exception.ServiceException;
import com.huimv.core.factory.PageFactory;
import com.huimv.core.pojo.page.PageResult;
import com.huimv.core.util.PoiUtil;

import com.huimv.modular.rawdata.entity.RawData;
import com.huimv.modular.rawdata.enums.RawDataExceptionEnum;
import com.huimv.modular.rawdata.mapper.RawDataMapper;
import com.huimv.modular.rawdata.param.RawDataParam;
import com.huimv.modular.rawdata.service.RawDataService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import javax.annotation.Resource;
import java.util.List;

/**
 * 原始数据存储service接口实现类
 *
 * @author yangdi
 * @date 2021-11-09 16:58:43
 */
@Service
public class RawDataServiceImpl extends ServiceImpl<RawDataMapper, RawData> implements RawDataService {

    @Override
    public PageResult<RawData> page(RawDataParam rawDataParam) {
        QueryWrapper<RawData> queryWrapper = new QueryWrapper<>();
        if (ObjectUtil.isNotNull(rawDataParam)) {

            // 根据 查询
            if (ObjectUtil.isNotEmpty(rawDataParam.getDetailData())) {
                queryWrapper.lambda().eq(RawData::getDetailData, rawDataParam.getDetailData());
            }
            // 根据 查询
            if (ObjectUtil.isNotEmpty(rawDataParam.getStatus())) {
                queryWrapper.lambda().eq(RawData::getStatus, rawDataParam.getStatus());
            }
        }
        return new PageResult<>(this.page(PageFactory.defaultPage(), queryWrapper));
    }



    @Override
    public PageResult<RawData> pageDesc(RawDataParam rawDataParam) {
        QueryWrapper<RawData> queryWrapper = new QueryWrapper<>();
        //需要倒序
        queryWrapper.orderByDesc("id");
        if (ObjectUtil.isNotNull(rawDataParam)) {
            // 根据 查询
            if (ObjectUtil.isNotEmpty(rawDataParam.getDetailData())) {
                queryWrapper.lambda().eq(RawData::getDetailData, rawDataParam.getDetailData());
            }
            // 根据 查询
            if (ObjectUtil.isNotEmpty(rawDataParam.getStatus())) {
                queryWrapper.lambda().eq(RawData::getStatus, rawDataParam.getStatus());
            }
        }
        return new PageResult<>(this.page(PageFactory.defaultPage(), queryWrapper));
    }














    @Override
    public List<RawData> list(RawDataParam rawDataParam) {
        return this.list();
    }

    @Override
    public void add(RawDataParam rawDataParam) {
        RawData rawData = new RawData();
        BeanUtil.copyProperties(rawDataParam, rawData);
        this.save(rawData);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<RawDataParam> rawDataParamList) {
        rawDataParamList.forEach(rawDataParam -> {
            this.removeById(rawDataParam.getId());
        });
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(RawDataParam rawDataParam) {
        RawData rawData = this.queryRawData(rawDataParam);
        BeanUtil.copyProperties(rawDataParam, rawData);
        this.updateById(rawData);
    }

    @Override
    public RawData detail(RawDataParam rawDataParam) {
        return this.queryRawData(rawDataParam);
    }

    /**
     * 获取原始数据存储
     *
     * @author yangdi
     * @date 2021-11-09 16:58:43
     */
    private RawData queryRawData(RawDataParam rawDataParam) {
        RawData rawData = this.getById(rawDataParam.getId());
        if (ObjectUtil.isNull(rawData)) {
            throw new ServiceException(RawDataExceptionEnum.NOT_EXIST);
        }
        return rawData;
    }

    @Override
    public void export(RawDataParam rawDataParam) {
        List<RawData> list = this.list(rawDataParam);
        PoiUtil.exportExcelWithStream("SnowyRawData.xls", RawData.class, list);
    }

}
