/*
Copyright [2020] [https://www.xiaonuo.vip]

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：

1.请不要删除和修改根目录下的LICENSE文件。
2.请不要删除和修改Snowy源码头部的版权声明。
3.请保留源码和相关描述文件的项目出处，作者声明等。
4.分发源码时候，请注明软件出处 https://gitee.com/xiaonuobase/snowy
5.在修改包名，模块名称，项目代码等时，请注明软件出处 https://gitee.com/xiaonuobase/snowy
6.若您的项目无法满足以上几点，可申请商业授权，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.huimv.modular.sowranktable.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.core.consts.CommonConstant;
import com.huimv.core.enums.CommonStatusEnum;
import com.huimv.core.exception.ServiceException;
import com.huimv.core.factory.PageFactory;
import com.huimv.core.pojo.page.PageResult;
import com.huimv.core.util.PoiUtil;
import com.huimv.modular.sowranktable.entity.SowRankTable;
import com.huimv.modular.sowranktable.enums.SowRankTableExceptionEnum;
import com.huimv.modular.sowranktable.mapper.SowRankTableMapper;
import com.huimv.modular.sowranktable.param.SowRankTableParam;
import com.huimv.modular.sowranktable.service.SowRankTableService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import javax.annotation.Resource;
import java.util.List;

/**
 * 母猪排名service接口实现类
 *
 * @author haohao
 * @date 2021-08-20 11:24:11
 */
@Service
public class SowRankTableServiceImpl extends ServiceImpl<SowRankTableMapper, SowRankTable> implements SowRankTableService {

    @Override
    public PageResult<SowRankTable> page(SowRankTableParam sowRankTableParam) {
        QueryWrapper<SowRankTable> queryWrapper = new QueryWrapper<>();
        if (ObjectUtil.isNotNull(sowRankTableParam)) {

            // 根据牧场名称 查询
            if (ObjectUtil.isNotEmpty(sowRankTableParam.getFarmName())) {
                queryWrapper.lambda().eq(SowRankTable::getFarmName, sowRankTableParam.getFarmName());
            }
            // 根据 查询
            if (ObjectUtil.isNotEmpty(sowRankTableParam.getFarmCode())) {
                queryWrapper.lambda().eq(SowRankTable::getFarmCode, sowRankTableParam.getFarmCode());
            }
            // 根据 查询
            if (ObjectUtil.isNotEmpty(sowRankTableParam.getFarmId())) {
                queryWrapper.lambda().eq(SowRankTable::getFarmId, sowRankTableParam.getFarmId());
            }
            // 根据母猪存栏 查询
            if (ObjectUtil.isNotEmpty(sowRankTableParam.getSowLivestock())) {
                queryWrapper.lambda().eq(SowRankTable::getSowLivestock, sowRankTableParam.getSowLivestock());
            }
            // 根据排名 查询
            if (ObjectUtil.isNotEmpty(sowRankTableParam.getSowLivestockRank())) {
                queryWrapper.lambda().eq(SowRankTable::getSowLivestockRank, sowRankTableParam.getSowLivestockRank());
            }
            // 根据存栏增长 查询
            if (ObjectUtil.isNotEmpty(sowRankTableParam.getSowLivestockInc())) {
                queryWrapper.lambda().eq(SowRankTable::getSowLivestockInc, sowRankTableParam.getSowLivestockInc());
            }
            // 根据排名 查询
            if (ObjectUtil.isNotEmpty(sowRankTableParam.getSowLivestockIncRank())) {
                queryWrapper.lambda().eq(SowRankTable::getSowLivestockIncRank, sowRankTableParam.getSowLivestockIncRank());
            }
            // 根据母猪msy 查询
            if (ObjectUtil.isNotEmpty(sowRankTableParam.getSowMsy())) {
                queryWrapper.lambda().eq(SowRankTable::getSowMsy, sowRankTableParam.getSowMsy());
            }
            // 根据排名 查询
            if (ObjectUtil.isNotEmpty(sowRankTableParam.getSowMsyRank())) {
                queryWrapper.lambda().eq(SowRankTable::getSowMsyRank, sowRankTableParam.getSowMsyRank());
            }
            // 根据统计 查询
            if (ObjectUtil.isNotEmpty(sowRankTableParam.getOutStockCount())) {
                queryWrapper.lambda().eq(SowRankTable::getOutStockCount, sowRankTableParam.getOutStockCount());
            }
            // 根据预计 查询
            if (ObjectUtil.isNotEmpty(sowRankTableParam.getOutStockExpected())) {
                queryWrapper.lambda().eq(SowRankTable::getOutStockExpected, sowRankTableParam.getOutStockExpected());
            }
            // 根据目标 查询
            if (ObjectUtil.isNotEmpty(sowRankTableParam.getAinOutStock())) {
                queryWrapper.lambda().eq(SowRankTable::getAinOutStock, sowRankTableParam.getAinOutStock());
            }
            // 根据完成度 查询
            if (ObjectUtil.isNotEmpty(sowRankTableParam.getFinishPercent())) {
                queryWrapper.lambda().eq(SowRankTable::getFinishPercent, sowRankTableParam.getFinishPercent());
            }
            // 根据备注 查询
            if (ObjectUtil.isNotEmpty(sowRankTableParam.getRemark())) {
                queryWrapper.lambda().eq(SowRankTable::getRemark, sowRankTableParam.getRemark());
            }
            // 根据排名备用 查询
            if (ObjectUtil.isNotEmpty(sowRankTableParam.getRank())) {
                queryWrapper.lambda().eq(SowRankTable::getRank, sowRankTableParam.getRank());
            }
        }
        return new PageResult<>(this.page(PageFactory.defaultPage(), queryWrapper));
    }

    @Override
    public List<SowRankTable> list(SowRankTableParam sowRankTableParam) {
        return this.list();
    }

    @Override
    public void add(SowRankTableParam sowRankTableParam) {
        SowRankTable sowRankTable = new SowRankTable();
        BeanUtil.copyProperties(sowRankTableParam, sowRankTable);
        this.save(sowRankTable);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<SowRankTableParam> sowRankTableParamList) {
        sowRankTableParamList.forEach(sowRankTableParam -> {
            this.removeById(sowRankTableParam.getId());
        });
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(SowRankTableParam sowRankTableParam) {
        SowRankTable sowRankTable = this.querySowRankTable(sowRankTableParam);
        BeanUtil.copyProperties(sowRankTableParam, sowRankTable);
        this.updateById(sowRankTable);
    }

    @Override
    public SowRankTable detail(SowRankTableParam sowRankTableParam) {
        return this.querySowRankTable(sowRankTableParam);
    }

    /**
     * 获取母猪排名
     *
     * @author haohao
     * @date 2021-08-20 11:24:11
     */
    private SowRankTable querySowRankTable(SowRankTableParam sowRankTableParam) {
        SowRankTable sowRankTable = this.getById(sowRankTableParam.getId());
        if (ObjectUtil.isNull(sowRankTable)) {
            throw new ServiceException(SowRankTableExceptionEnum.NOT_EXIST);
        }
        return sowRankTable;
    }

    @Override
    public void export(SowRankTableParam sowRankTableParam) {
        List<SowRankTable> list = this.list(sowRankTableParam);
        PoiUtil.exportExcelWithStream("SnowySowRankTable.xls", SowRankTable.class, list);
    }

}
